<?php

namespace App\Http\Controllers;

use App\Models\user_model;
use App\Models\budget_model;
use App\Models\login_model;
use Illuminate\Http\Request;

class user_controller extends Controller
{
    protected $users;
    protected $budgets;
    protected $login;

    public function __construct()
    {
        $this->users = new user_model;
        $this->budgets = new budget_model;
        $this->login = new login_model;
    }

    public function users_list(){

        $users = $this->users->all();

        $data = compact('users');
//        dd(session()->all());
        return view('users')->with($data);

    }

    public function add_user(){

        $url = route('user_form');
        $title = 'Add User';

        $user = $this->users;
        $budgets = $this->budgets->all();

        $data = compact('budgets','user','url','title');

        return view('user_form')->with($data);
    }

    public function store_user(Request $request){

        $request->validate([
            'name' => 'required',
            'email' => 'email|required|unique:users_table,email',
            'phone' => 'required|unique:users_table,phone',
            'password' => 'required|min:6',
            'budget' => 'required_without:custom_budget', // Ensure budget is required if custom_budget is not provided
            'custom_budget' => 'required_without:budget', // Ensure custom_budget is required if budget is not provided
        ]);

        $this->users->name = $request['name'];
        $this->users->email = $request['email'];
        $this->users->password = $request['password'];
        $this->users->phone = $request['phone'];
        $this->users->address = $request['address'];
        if($request['budget']){
            $this->users->budget = $request['budget'];
        }elseif($request['custom_budget']){
            $this->users->budget = $request['custom_budget'];
        }
        $this->users->save();


        $this->login->userid = $this->users->id;
        $this->login->name = $request['name'];
        $this->login->password = $request->password;
        $this->login->status = 'user';
        $this->login->save();

        return redirect(route('users'));
    }

    public function delete($id){

        $user = $this->users->find($id);

        if(!is_null($user)){
            $user->delete();
        }

        return redirect(route('users'));
    }


    public function edit($id){

        $user = $this->users->find($id);
        $budgets = $this->budgets->all();


        if(is_null($user)){
            return redirect(route('users'));
        }else{

            $url = route('update_user', ['id' => $id]);
            $title = 'Edit User';

            $data = compact('budgets','user','url','title');

            return view('user_form')->with($data);
        }
    }

    public function update($id,Request $request){

        $request->validate([
            'name' => 'required',
            'email' => 'required|email|unique:users_table,email,' . $id,
            'phone' => 'required|unique:users_table,phone,' . $id,
            'password' => 'required|min:6',
            'budget' => 'required_without:custom_budget', // Ensure budget is required if custom_budget is not provided
            'custom_budget' => 'required_without:budget', // Ensure custom_budget is required if budget is not provided
        ]);

        $user = $this->users->find($id);
        if (!$user) {
            return redirect(route('users'));
        }

        $user->name = $request['name'];
        $user->email = $request['email'];
        $user->password = $request['password'];
        $user->phone = $request['phone'];
        $user->address = $request['address'];
        if($request['budget']){
            $user->budget = $request['budget'];
        }elseif($request['custom_budget']){
            $user->budget = $request['custom_budget'];
        }
        $user->save();


        $login = $this->login->where('userid', $user->id)->first();
        if (!$login) {
            $login = new login_model;
            $login->userid = $user->id;
        }

        $login->name = $request['name'];
        $login->password = $request['password'];
        $login->status = 'user';
        $login->save();

        return redirect(route('users'));
    }
}
